import { DeepARInterface } from "../../deeparInterface";
import { ParameterNamespace } from "./parameterNamespace";
import { PluginParameter } from "./parameters";
import { ExportType, ImportInfo, ParameterInfo, ParameterType } from "../../parameterTypes";
declare function initializePluginRunner(deepaAR: DeepARInterface, rootPath: string): Promise<PluginRunner>;
interface ParameterContext {
    namespace: ParameterNamespace;
    name: string;
    parameter: PluginParameter;
    spec: any;
}
declare class PluginRunner {
    private readonly deepaAR;
    private readonly rootPath;
    private beautySpec;
    private namespace;
    private parametersByFqName;
    private namespacesByFqName;
    private disablersByFqName;
    private effectController;
    private effectControllerPromise;
    private readonly parametersInfo;
    readonly pluginName: string;
    readonly pluginVersion: string;
    private textures;
    private colorsRGB;
    private colorsRGBA;
    private floats;
    private effects;
    constructor(deepaAR: DeepARInterface, rootPath: string);
    init(): Promise<void>;
    shutdown(): void;
    setLogoVisible(isVisible: boolean): Promise<void>;
    getWatermarkEffectPath(): string;
    getWatermarkImagePath(): string;
    private parseDefaultRequiredEffects;
    private parseLoadAndUnloadEffectAtInitialize;
    private parseParameters;
    private parseAllResources;
    private parseResources;
    private parseNamespace;
    private parseParameter;
    private checkDefaultValue;
    private checkPrepackaged;
    private lookupTexture;
    private lookupFloat;
    private lookupColorRGB;
    private lookupColorRGBA;
    private lookupResource;
    isParameterDisabler(fqName: string): boolean;
    callParameterSetTemplate(paramFQName: string, template: string): Promise<void>;
    callParameterSet(paramFQName: string, value: ParameterType, id?: string): Promise<void>;
    callReset(FQName: string): Promise<void>;
    callDisable(FQName: string, isDisabled: boolean): Promise<void>;
    private callDisableOnNamespace;
    private callParameterSetInternal;
    callParameterGet(param: string): ParameterType;
    callParameterGetId(param: string): string | null;
    callParameterGetTemplateValue(paramFQName: string, template: string): ParameterType;
    callParameterGetTemplates(paramFQName: string): string[];
    callExportPreset(exportType: ExportType): Promise<Blob>;
    callImportPreset(presetZip: string | Blob, overrideImportType?: ExportType): Promise<ImportInfo>;
    getParametersInfo(): ParameterInfo[];
    private getParameterTemplateValue;
    private getParameterByName;
    private getNamespaceByName;
    private getParameterContextByName;
    private runRequireEffectIf;
    private runTransform;
    private runChangeParameter;
    private translateActionParameters;
    private static convertParametersToParameterInfo;
    private getAssetPath;
    private getEffectPath;
    private getEffect;
}
export { initializePluginRunner, PluginRunner, ParameterContext };
